#!/bin/sh
#
# Spell a file & generate the syntax statements necessary to
# highlight in vim.  Based on a program from Krishna Gadepalli
# <krishna@stdavids.picker.com>.
#
# I use the following mappings (in .vimrc):
#
#	noremap <F8> :so `vimspell.sh %`<CR><CR>
#	noremap <F7> :syntax clear SpellErrors<CR>
#
# Neil Schemenauer <nascheme@ucalgary.ca>
# March 1999

INFILE=$1
OUTFILE=/tmp/vimspell.$$

#
# local spellings
#
LOCAL_DICT=${LOCAL_DICT-$HOME/.vim/local_dict}


if [ $(which aspell) ] ; then
	SPELL="aspell"
	SPELLOPT="--lang=czech --mode=tex"
	if [ -f $LOCAL_DICT ]
	then
		SPELL_ARGS="--personal=$LOCAL_DICT"
	fi
else
	SPELL="ispell"
	SPELLOPT="-d czech -L 5 -x -t"
	if [ -f $LOCAL_DICT ]
	then
		SPELL_ARGS="+$LOCAL_DICT"
	fi
fi

				

# if you have "tempfile", use the following line
#OUTFILE=`tempfile`


cat  $INFILE | $SPELL $SPELLOPT -l $SPELL_ARGS | sort -u |
awk '
      {
      	printf "syntax match SpellErrors \"\\<%s\\>\"\n", $0 ;
      }

END   {
	printf "highlight link SpellErrors ErrorMsg\n\n" ;
      }
' > $OUTFILE
echo "!rm $OUTFILE" >> $OUTFILE
echo $OUTFILE
